@@ -34,7 +34,7 @@ from aiida.common import StashMode, exceptions
 from aiida.engine import run, submit
 from aiida.engine.daemon.client import get_daemon_client
 from aiida.engine.persistence import ObjectLoader
-from aiida.engine.processes import Process
+from aiida.engine.processes import CalcJob, Process
 from aiida.manage.caching import enable_caching
 from aiida.orm import CalcJobNode, Dict, Int, List, Str, load_code, load_node
 from aiida.plugins import CalculationFactory, WorkflowFactory
@@ -411,6 +411,20 @@ def run_multiply_add_workchain():
     assert results['result'].value == 5
 
 
+def run_monitored_calculation():
+    """Run a monitored calculation."""
+    builder = load_code(CODENAME_ADD).get_builder()
+    builder.x = Int(1)
+    builder.y = Int(2)
+    builder.metadata.options.sleep = 2  # Add a sleep to the calculation to ensure monitor has time to get called
+    builder.monitors = {'always_kill': Dict({'entry_point': 'core.always_kill'})}
+
+    _, node = run.get_node(builder)
+    assert node.is_terminated
+    assert node.exit_status == CalcJob.exit_codes.STOPPED_BY_MONITOR.status
+    assert node.exit_message == 'Detected a non-empty submission script', node.exit_message
+
+
 def launch_all():
     """Launch a bunch of calculation jobs and workchains.
 
@@ -435,6 +449,7 @@ def launch_all():
     run_multiply_add_workchain()
 
     # Testing the stashing functionality
+    print('Testing the stashing functionality')
     process, inputs, expected_result = create_calculation_process(code=code_doubler, inputval=1)
     with tempfile.TemporaryDirectory() as tmpdir:
 
@@ -458,6 +473,10 @@ def launch_all():
             else:
                 assert filename in stashed_filenames
 
+    # Testing the monitoring functionality
+    print('Testing the monitoring functionality')
+    run_monitored_calculation()
+
     # Submitting the calcfunction through the launchers
     print('Submitting calcfunction to the daemon')
     proc, expected_result = launch_calcfunction(inputval=1)
