@@ -8,7 +8,7 @@
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 """A namedtuple and namespace for ExitCodes that can be used to exit from Processes."""
-from typing import NamedTuple, Optional
+from typing import NamedTuple, Optional, Union
 
 from aiida.common.extendeddicts import AttributeDict
 
@@ -55,7 +55,7 @@ class ExitCodesNamespace(AttributeDict):
     `ExitCode` that needs to be retrieved or the key in the collection.
     """
 
-    def __call__(self, identifier: str) -> ExitCode:
+    def __call__(self, identifier: Union[int, str]) -> ExitCode:
         """Return a specific exit code identified by either its exit status or label.
 
         :param identifier: the identifier of the exit code. If the type is integer, it will be interpreted as the exit
