@@ -24,7 +24,7 @@ def to_aiida_type(value):
 class BaseType(Data):
     """`Data` sub class to be used as a base for data containers that represent base python data types."""
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, value=None, **kwargs):
         try:
             getattr(self, '_type')
         except AttributeError:
@@ -32,20 +32,15 @@ class BaseType(Data):
 
         super().__init__(**kwargs)
 
-        try:
-            value = args[0]
-        except IndexError:
-            value = self._type()  # pylint: disable=no-member
-
-        self.value = value
+        self.value = value or self._type()  # pylint: disable=no-member
 
     @property
     def value(self):
-        return self.get_attribute('value', None)
+        return self.base.attributes.get('value', None)
 
     @value.setter
     def value(self, value):
-        self.set_attribute('value', self._type(value))  # pylint: disable=no-member
+        self.base.attributes.set('value', self._type(value))  # pylint: disable=no-member
 
     def __str__(self):
         return f'{super().__str__()} value: {self.value}'
@@ -55,10 +50,5 @@ class BaseType(Data):
             return self.value == other.value
         return self.value == other
 
-    def __ne__(self, other):
-        if isinstance(other, BaseType):
-            return self.value != other.value
-        return self.value != other
-
     def new(self, value=None):
         return self.__class__(value)
