@@ -2,6 +2,7 @@
 """Data plugin that models an archived folder on a remote computer."""
 from aiida.common.datastructures import StashMode
 from aiida.common.lang import type_check
+
 from ...data import Data
 
 __all__ = ('RemoteStashData',)
@@ -40,7 +41,7 @@ class RemoteStashData(Data):
 
         :return: the stash mode.
         """
-        return StashMode(self.get_attribute('stash_mode'))
+        return StashMode(self.base.attributes.get('stash_mode'))
 
     @stash_mode.setter
     def stash_mode(self, value: StashMode):
@@ -49,4 +50,4 @@ class RemoteStashData(Data):
         :param value: the stash mode.
         """
         type_check(value, StashMode)
-        self.set_attribute('stash_mode', value.value)
+        self.base.attributes.set('stash_mode', value.value)
