@@ -12,6 +12,7 @@ import json
 import re
 
 from upf_to_json import upf_to_json
+
 from .singlefile import SinglefileData
 
 __all__ = ('UpfData',)
@@ -46,7 +47,7 @@ def get_pseudos_from_structure(structure, family_name):
     :raise aiida.common.MultipleObjectsError: if more than one UPF for the same element is found in the group.
     :raise aiida.common.NotExistent: if no UPF for an element in the group is found in the group.
     """
-    from aiida.common.exceptions import NotExistent, MultipleObjectsError
+    from aiida.common.exceptions import MultipleObjectsError, NotExistent
 
     pseudo_list = {}
     family_pseudos = {}
@@ -69,7 +70,7 @@ def get_pseudos_from_structure(structure, family_name):
     return pseudo_list
 
 
-def upload_upf_family(folder, group_label, group_description, stop_if_existing=True):
+def upload_upf_family(folder, group_label, group_description, stop_if_existing=True, backend=None):
     """Upload a set of UPF files in a given group.
 
     :param folder: a path containing all UPF files to be added.
@@ -100,8 +101,8 @@ def upload_upf_family(folder, group_label, group_description, stop_if_existing=T
 
     nfiles = len(filenames)
 
-    automatic_user = orm.User.objects.get_default()
-    group, group_created = orm.UpfFamily.objects.get_or_create(label=group_label, user=automatic_user)
+    automatic_user = orm.User.collection.get_default()
+    group, group_created = orm.UpfFamily.collection.get_or_create(label=group_label, user=automatic_user)
 
     if group.user.email != automatic_user.email:
         raise UniquenessError(
@@ -119,9 +120,9 @@ def upload_upf_family(folder, group_label, group_description, stop_if_existing=T
 
     for filename in filenames:
         md5sum = md5_file(filename)
-        builder = orm.QueryBuilder()
+        builder = orm.QueryBuilder(backend=backend)
         builder.append(UpfData, filters={'attributes.md5': {'==': md5sum}})
-        existing_upf = builder.first()
+        existing_upf = builder.first(flat=True)
 
         if existing_upf is None:
             # return the upfdata instances, not stored
@@ -132,7 +133,6 @@ def upload_upf_family(folder, group_label, group_description, stop_if_existing=T
         else:
             if stop_if_existing:
                 raise ValueError(f'A UPF with identical MD5 to  {filename} cannot be added with stop_if_existing')
-            existing_upf = existing_upf[0]
             pseudo_and_created.append((existing_upf, False))
 
     # check whether pseudo are unique per element
@@ -176,7 +176,7 @@ def upload_upf_family(folder, group_label, group_description, stop_if_existing=T
     return nfiles, nuploaded
 
 
-def parse_upf(fname, check_filename=True):
+def parse_upf(fname, check_filename=True, encoding='utf-8'):
     """
     Try to get relevant information from the UPF. For the moment, only the
     element name. Note that even UPF v.2 cannot be parsed with the XML minidom!
@@ -185,20 +185,24 @@ def parse_upf(fname, check_filename=True):
     If check_filename is True, raise a ParsingError exception if the filename
     does not start with the element name.
     """
+    # pylint: disable=too-many-branches
     import os
 
-    from aiida.common.exceptions import ParsingError
     from aiida.common import AIIDA_LOGGER
+    from aiida.common.exceptions import ParsingError
     from aiida.orm.nodes.data.structure import _valid_symbols
 
     parsed_data = {}
 
     try:
         upf_contents = fname.read()
-        fname = fname.name
     except AttributeError:
-        with open(fname, encoding='utf8') as handle:
+        with open(fname, encoding=encoding) as handle:
             upf_contents = handle.read()
+    else:
+        if check_filename:
+            raise ValueError('cannot use filelike objects when `check_filename=True`, use a filepath instead.')
+        fname = 'file.txt'
 
     match = REGEX_UPF_VERSION.search(upf_contents)
     if match:
@@ -248,19 +252,6 @@ def parse_upf(fname, check_filename=True):
 class UpfData(SinglefileData):
     """`Data` sub class to represent a pseudopotential single file in UPF format."""
 
-    def __init__(self, file=None, filename=None, source=None, **kwargs):
-        """Create UpfData instance from pseudopotential file.
-
-          :param file: filepath or filelike object of the UPF potential file to store.
-            Hint: Pass io.BytesIO(b"my string") to construct directly from a string.
-          :param filename: specify filename to use (defaults to name of provided file).
-          :param source: Dictionary with information on source of the potential (see ".source" property).
-          """
-        # pylint: disable=redefined-builtin
-        super().__init__(file, filename=filename, **kwargs)
-        if source is not None:
-            self.set_source(source)
-
     @classmethod
     def get_or_create(cls, filepath, use_first=False, store_upf=True):
         """Get the `UpfData` with the same md5 of the given file, or create it if it does not yet exist.
@@ -272,6 +263,7 @@ class UpfData(SinglefileData):
         :return: tuple of `UpfData` and boolean indicating whether it was created.
         """
         import os
+
         from aiida.common.files import md5_file
 
         if not os.path.isabs(filepath):
@@ -305,8 +297,13 @@ class UpfData(SinglefileData):
         if self.is_stored:
             return self
 
+        # Do not check the filename because it will fail since we are passing in a handle, which doesn't have a filename
+        # and so `parse_upf` will raise. The reason we have to pass in a handle is because this is the repository does
+        # not allow to get an absolute filepath. Anyway, the filename was already checked in `set_file` when the file
+        # was set for the first time. All the logic in this method is duplicated in `store` and `_validate` and badly
+        # needs to be refactored, but that is for another time.
         with self.open(mode='r') as handle:
-            parsed_data = parse_upf(handle)
+            parsed_data = parse_upf(handle, check_filename=False)
 
         # Open in binary mode which is required for generating the md5 checksum
         with self.open(mode='rb') as handle:
@@ -317,13 +314,13 @@ class UpfData(SinglefileData):
         except KeyError:
             raise ParsingError(f'Could not parse the element from the UPF file {self.filename}')
 
-        self.set_attribute('element', str(element))
-        self.set_attribute('md5', md5)
+        self.base.attributes.set('element', str(element))
+        self.base.attributes.set('md5', md5)
 
         return super().store(*args, **kwargs)
 
     @classmethod
-    def from_md5(cls, md5):
+    def from_md5(cls, md5, backend=None):
         """Return a list of all `UpfData` that match the given md5 hash.
 
         .. note:: assumes hash of stored `UpfData` nodes is stored in the `md5` attribute
@@ -332,7 +329,7 @@ class UpfData(SinglefileData):
         :return: list of existing `UpfData` nodes that have the same md5 hash
         """
         from aiida.orm.querybuilder import QueryBuilder
-        builder = QueryBuilder()
+        builder = QueryBuilder(backend=backend)
         builder.append(cls, filters={'attributes.md5': {'==': md5}})
         return builder.all(flat=True)
 
@@ -361,17 +358,16 @@ class UpfData(SinglefileData):
 
         super().set_file(file, filename=filename)
 
-        self.set_attribute('element', str(element))
-        self.set_attribute('md5', md5sum)
+        self.base.attributes.set('element', str(element))
+        self.base.attributes.set('md5', md5sum)
 
     def get_upf_family_names(self):
         """Get the list of all upf family names to which the pseudo belongs."""
-        from aiida.orm import UpfFamily
-        from aiida.orm import QueryBuilder
+        from aiida.orm import QueryBuilder, UpfFamily
 
-        query = QueryBuilder()
+        query = QueryBuilder(backend=self.backend)
         query.append(UpfFamily, tag='group', project='label')
-        query.append(UpfData, filters={'id': {'==': self.id}}, with_group='group')
+        query.append(UpfData, filters={'id': {'==': self.pk}}, with_group='group')
         return query.all(flat=True)
 
     @property
@@ -380,7 +376,7 @@ class UpfData(SinglefileData):
 
         :return: the element
         """
-        return self.get_attribute('element', None)
+        return self.base.attributes.get('element', None)
 
     @property
     def md5sum(self):
@@ -388,7 +384,7 @@ class UpfData(SinglefileData):
 
         :return: the md5 checksum
         """
-        return self.get_attribute('md5', None)
+        return self.base.attributes.get('md5', None)
 
     def _validate(self):
         """Validate the UPF potential file stored for this node."""
@@ -397,8 +393,13 @@ class UpfData(SinglefileData):
 
         super()._validate()
 
+        # Do not check the filename because it will fail since we are passing in a handle, which doesn't have a filename
+        # and so `parse_upf` will raise. The reason we have to pass in a handle is because this is the repository does
+        # not allow to get an absolute filepath. Anyway, the filename was already checked in `set_file` when the file
+        # was set for the first time. All the logic in this method is duplicated in `store` and `_validate` and badly
+        # needs to be refactored, but that is for another time.
         with self.open(mode='r') as handle:
-            parsed_data = parse_upf(handle)
+            parsed_data = parse_upf(handle, check_filename=False)
 
         # Open in binary mode which is required for generating the md5 checksum
         with self.open(mode='rb') as handle:
@@ -410,12 +411,12 @@ class UpfData(SinglefileData):
             raise ValidationError(f"No 'element' could be parsed in the UPF {self.filename}")
 
         try:
-            attr_element = self.get_attribute('element')
+            attr_element = self.base.attributes.get('element')
         except AttributeError:
             raise ValidationError("attribute 'element' not set.")
 
         try:
-            attr_md5 = self.get_attribute('md5')
+            attr_md5 = self.base.attributes.get('md5')
         except AttributeError:
             raise ValidationError("attribute 'md5' not set.")
 
@@ -446,7 +447,7 @@ class UpfData(SinglefileData):
         return UpfFamily.get(label=group_label)
 
     @classmethod
-    def get_upf_groups(cls, filter_elements=None, user=None):
+    def get_upf_groups(cls, filter_elements=None, user=None, backend=None):
         """Return all names of groups of type UpfFamily, possibly with some filters.
 
         :param filter_elements: A string or a list of strings.
@@ -456,11 +457,9 @@ class UpfData(SinglefileData):
             If defined, it should be either a `User` instance or the user email.
         :return: list of `Group` entities of type UPF.
         """
-        from aiida.orm import UpfFamily
-        from aiida.orm import QueryBuilder
-        from aiida.orm import User
+        from aiida.orm import QueryBuilder, UpfFamily, User
 
-        builder = QueryBuilder()
+        builder = QueryBuilder(backend=backend)
         builder.append(UpfFamily, tag='group', project='*')
 
         if user:
