@@ -16,7 +16,7 @@ import pathlib
 from typing import TYPE_CHECKING, Iterator, List, Optional, Sequence, Set, Union
 
 from disk_objectstore import Container
-from sqlalchemy import table
+from sqlalchemy.exc import IntegrityError as SqlaIntegrityError
 from sqlalchemy.orm import Session, scoped_session, sessionmaker
 
 from aiida.common.exceptions import ClosedStorage, ConfigurationError, IntegrityError
@@ -24,7 +24,7 @@ from aiida.manage.configuration.profile import Profile
 from aiida.orm.entities import EntityTypes
 from aiida.orm.implementation import BackendEntity, StorageBackend
 from aiida.storage.log import STORAGE_LOGGER
-from aiida.storage.psql_dos.migrator import REPOSITORY_UUID_KEY, PsqlDostoreMigrator
+from aiida.storage.psql_dos.migrator import REPOSITORY_UUID_KEY, PsqlDosMigrator
 from aiida.storage.psql_dos.models import base
 
 from .orm import authinfos, comments, computers, convert, groups, logs, nodes, querybuilder, users
@@ -71,7 +71,7 @@ class PsqlDosBackend(StorageBackend):  # pylint: disable=too-many-public-methods
     The `django` backend was removed, to consolidate access to this storage.
     """
 
-    migrator = PsqlDostoreMigrator
+    migrator = PsqlDosMigrator
 
     @classmethod
     def version_head(cls) -> str:
@@ -79,17 +79,34 @@ class PsqlDosBackend(StorageBackend):  # pylint: disable=too-many-public-methods
 
     @classmethod
     def version_profile(cls, profile: Profile) -> Optional[str]:
-        return cls.migrator(profile).get_schema_version_profile(check_legacy=True)
+        with cls.migrator_context(profile) as migrator:
+            return migrator.get_schema_version_profile(check_legacy=True)
+
+    @classmethod
+    def initialise(cls, profile: Profile, reset: bool = False) -> bool:
+        with cls.migrator_context(profile) as migrator:
+            return migrator.initialise(reset=reset)
 
     @classmethod
     def migrate(cls, profile: Profile) -> None:
-        cls.migrator(profile).migrate()
+        with cls.migrator_context(profile) as migrator:
+            migrator.migrate()
+
+    @classmethod
+    @contextmanager
+    def migrator_context(cls, profile: Profile):
+        migrator = cls.migrator(profile)
+        try:
+            yield migrator
+        finally:
+            migrator.close()
 
     def __init__(self, profile: Profile) -> None:
         super().__init__(profile)
 
         # check that the storage is reachable and at the correct version
-        self.migrator(profile).validate_storage()
+        with self.migrator_context(profile) as migrator:
+            migrator.validate_storage()
 
         self._session_factory: Optional[scoped_session] = None
         self._initialise_session()
@@ -109,9 +126,8 @@ class PsqlDosBackend(StorageBackend):  # pylint: disable=too-many-public-methods
         return self._session_factory is None
 
     def __str__(self) -> str:
-        repo_uri = self.profile.storage_config['repository_uri']
         state = 'closed' if self.is_closed else 'open'
-        return f'Storage for {self.profile.name!r} [{state}] @ {self._db_url!r} / {repo_uri}'
+        return f'Storage for {self.profile.name!r} [{state}] @ {self._db_url!r} / {self.get_repository()}'
 
     def _initialise_session(self):
         """Initialise the SQLAlchemy session factory.
@@ -124,7 +140,7 @@ class PsqlDosBackend(StorageBackend):  # pylint: disable=too-many-public-methods
         Although, in the future, we may want to move the multi-thread handling to higher in the AiiDA stack.
         """
         from aiida.storage.psql_dos.utils import create_sqlalchemy_engine
-        engine = create_sqlalchemy_engine(self._profile.storage_config)
+        engine = create_sqlalchemy_engine(self._profile.storage_config)  # type: ignore
         self._session_factory = scoped_session(sessionmaker(bind=engine, future=True, expire_on_commit=True))
 
     def get_session(self) -> Session:
@@ -149,48 +165,35 @@ class PsqlDosBackend(StorageBackend):  # pylint: disable=too-many-public-methods
         # in sqlalchemy.orm.session._sessions
         gc.collect()
 
-    def _clear(self, recreate_user: bool = True) -> None:
+    def _clear(self) -> None:
         from aiida.storage.psql_dos.models.settings import DbSetting
-        from aiida.storage.psql_dos.models.user import DbUser
 
-        super()._clear(recreate_user)
+        super()._clear()
 
-        session = self.get_session()
+        with self.migrator_context(self._profile) as migrator:
 
-        # clear the database
-        with self.transaction():
+            # First clear the contents of the database
+            with self.transaction() as session:
 
-            # save the default user
-            default_user_kwargs = None
-            if recreate_user and self.default_user is not None:
-                default_user_kwargs = {
-                    'email': self.default_user.email,
-                    'first_name': self.default_user.first_name,
-                    'last_name': self.default_user.last_name,
-                    'institution': self.default_user.institution,
-                }
+                # Close the session otherwise the ``delete_tables`` call will hang as there will be an open connection
+                # to the PostgreSQL server and it will block the deletion and the command will hang.
+                self.get_session().close()
+                exclude_tables = [migrator.alembic_version_tbl_name, 'db_dbsetting']
+                migrator.delete_all_tables(exclude_tables=exclude_tables)
 
-            # now clear the database
-            for table_name in (
-                'db_dbgroup_dbnodes', 'db_dbgroup', 'db_dblink', 'db_dbnode', 'db_dblog', 'db_dbauthinfo', 'db_dbuser',
-                'db_dbcomputer'
-            ):
-                session.execute(table(table_name).delete())
-            session.expunge_all()
-            self._default_user = None
+                # Clear out all references to database model instances which are now invalid.
+                session.expunge_all()
 
-            # restore the default user
-            if recreate_user and default_user_kwargs:
-                session.add(DbUser(**default_user_kwargs))
+            # Now reset and reinitialise the repository
+            migrator.reset_repository()
+            migrator.initialise_repository()
+            repository_uuid = migrator.get_repository_uuid()
 
-        # Clear the repository and reset the repository UUID
-        container = Container(str(get_filepath_container(self.profile)))
-        container.init_container(clear=True, **CONTAINER_DEFAULTS)
-        container_id = container.container_id
-        with self.transaction():
-            session.execute(
-                DbSetting.__table__.update().where(DbSetting.key == REPOSITORY_UUID_KEY).values(val=container_id)
-            )
+            with self.transaction():
+                session.execute(
+                    DbSetting.__table__.update().where(DbSetting.key == REPOSITORY_UUID_KEY
+                                                       ).values(val=repository_uuid)
+                )
 
     def get_repository(self) -> 'DiskObjectStoreRepositoryBackend':
         from aiida.repository.backend import DiskObjectStoreRepositoryBackend
@@ -230,20 +233,23 @@ class PsqlDosBackend(StorageBackend):  # pylint: disable=too-many-public-methods
 
     @contextmanager
     def transaction(self) -> Iterator[Session]:
-        """Open a transaction to be used as a context manager.
+        """Open a transaction and yield the current session.
 
         If there is an exception within the context then the changes will be rolled back and the state will be as before
-        entering. Transactions can be nested.
+        entering, otherwise the changes will be commited and the transaction closed. Transactions can be nested.
         """
         session = self.get_session()
-        if session.in_transaction():
-            with session.begin_nested():
-                yield session
-            session.commit()
-        else:
-            with session.begin():
+
+        try:
+            if session.in_transaction():
                 with session.begin_nested():
                     yield session
+            else:
+                with session.begin():
+                    with session.begin_nested():
+                        yield session
+        except SqlaIntegrityError as exception:
+            raise IntegrityError(str(exception)) from exception
 
     @property
     def in_transaction(self) -> bool:
@@ -321,19 +327,16 @@ class PsqlDosBackend(StorageBackend):  # pylint: disable=too-many-public-methods
         from aiida.storage.psql_dos.models.group import DbGroupNode
         from aiida.storage.psql_dos.models.node import DbLink, DbNode
 
-        if not self.in_transaction:
-            raise AssertionError('Cannot delete nodes and links outside a transaction')
-
-        session = self.get_session()
-        # Delete the membership of these nodes to groups.
-        session.query(DbGroupNode).filter(DbGroupNode.dbnode_id.in_(list(pks_to_delete))
-                                          ).delete(synchronize_session='fetch')
-        # Delete the links coming out of the nodes marked for deletion.
-        session.query(DbLink).filter(DbLink.input_id.in_(list(pks_to_delete))).delete(synchronize_session='fetch')
-        # Delete the links pointing to the nodes marked for deletion.
-        session.query(DbLink).filter(DbLink.output_id.in_(list(pks_to_delete))).delete(synchronize_session='fetch')
-        # Delete the actual nodes
-        session.query(DbNode).filter(DbNode.id.in_(list(pks_to_delete))).delete(synchronize_session='fetch')
+        with self.transaction() as session:
+            # Delete the membership of these nodes to groups.
+            session.query(DbGroupNode).filter(DbGroupNode.dbnode_id.in_(list(pks_to_delete))
+                                              ).delete(synchronize_session='fetch')
+            # Delete the links coming out of the nodes marked for deletion.
+            session.query(DbLink).filter(DbLink.input_id.in_(list(pks_to_delete))).delete(synchronize_session='fetch')
+            # Delete the links pointing to the nodes marked for deletion.
+            session.query(DbLink).filter(DbLink.output_id.in_(list(pks_to_delete))).delete(synchronize_session='fetch')
+            # Delete the actual nodes
+            session.query(DbNode).filter(DbNode.id.in_(list(pks_to_delete))).delete(synchronize_session='fetch')
 
     def get_backend_entity(self, model: base.Base) -> BackendEntity:
         """
@@ -377,7 +380,7 @@ class PsqlDosBackend(StorageBackend):  # pylint: disable=too-many-public-methods
         if full:
             maintenance_context = ProfileAccessManager(self._profile).lock
         else:
-            maintenance_context = nullcontext
+            maintenance_context = nullcontext  # type: ignore
 
         with maintenance_context():
             unreferenced_objects = self.get_unreferenced_keyset()
