@@ -14,9 +14,10 @@ from contextlib import contextmanager
 from functools import cached_property
 from typing import Any, Iterator, Sequence
 
+from sqlalchemy.exc import IntegrityError as SqlaIntegrityError
 from sqlalchemy.orm import Session
 
-from aiida.common.exceptions import ClosedStorage
+from aiida.common.exceptions import ClosedStorage, IntegrityError
 from aiida.manage import Profile, get_config_option
 from aiida.orm.entities import EntityTypes
 from aiida.orm.implementation import BackendEntity, StorageBackend
@@ -70,6 +71,10 @@ class SqliteTempBackend(StorageBackend):  # pylint: disable=too-many-public-meth
     def version_profile(cls, profile: Profile) -> str | None:  # pylint: disable=unused-argument
         return get_schema_version_head()
 
+    @classmethod
+    def initialise(cls, profile: 'Profile', reset: bool = False) -> bool:  # pylint: disable=unused-argument
+        return False
+
     @classmethod
     def migrate(cls, profile: Profile):
         pass
@@ -140,16 +145,19 @@ class SqliteTempBackend(StorageBackend):  # pylint: disable=too-many-public-meth
         entering. Transactions can be nested.
         """
         session = self.get_session()
-        if session.in_transaction():
-            with session.begin_nested():
-                yield session
-            session.commit()
-        else:
-            with session.begin():
+
+        try:
+            if session.in_transaction():
                 with session.begin_nested():
                     yield session
+            else:
+                with session.begin():
+                    with session.begin_nested():
+                        yield session
+        except SqlaIntegrityError as exception:
+            raise IntegrityError(str(exception)) from exception
 
-    def _clear(self, recreate_user: bool = True) -> None:
+    def _clear(self) -> None:
         raise NotImplementedError
 
     def maintain(self, dry_run: bool = False, live: bool = True, **kwargs) -> None:
