@@ -109,6 +109,7 @@ def _get_aiida_structure_pymatgen_inline(cif, **kwargs):
     .. note:: requires pymatgen module.
     """
     from pymatgen.io.cif import CifParser
+
     from aiida.orm import Dict, StructureData
 
     parameters = kwargs.get('parameters', {})
@@ -191,19 +192,20 @@ def refine_inline(node):
 
     # Remove all existing symmetry tags before overwriting:
     for tag in symmetry_tags:
-        cif.values[name].RemoveCifItem(tag)
+        cif.values[name].RemoveCifItem(tag)  # pylint: disable=unsubscriptable-object
 
-    cif.values[name]['_symmetry_space_group_name_H-M'] = symmetry['hm']
-    cif.values[name]['_symmetry_space_group_name_Hall'] = symmetry['hall']
-    cif.values[name]['_symmetry_Int_Tables_number'] = symmetry['tables']
-    cif.values[name]['_symmetry_equiv_pos_as_xyz'] = \
-        [symop_string_from_symop_matrix_tr(symmetry['rotations'][i],
-                                           symmetry['translations'][i])
-         for i in range(len(symmetry['rotations']))]
+    cif.values[name]['_symmetry_space_group_name_H-M'] = symmetry['hm']  # pylint: disable=unsubscriptable-object
+    cif.values[name]['_symmetry_space_group_name_Hall'] = symmetry['hall']  # pylint: disable=unsubscriptable-object
+    cif.values[name]['_symmetry_Int_Tables_number'] = symmetry['tables']  # pylint: disable=unsubscriptable-object
+    cif.values[name]['_symmetry_equiv_pos_as_xyz'] = [  # pylint: disable=unsubscriptable-object
+        symop_string_from_symop_matrix_tr(symmetry['rotations'][i], symmetry['translations'][i])
+        for i in range(len(symmetry['rotations']))
+    ]
 
     # Summary formula has to be calculated from non-reduced set of atoms.
-    cif.values[name]['_chemical_formula_sum'] = \
+    cif.values[name]['_chemical_formula_sum'] = (  # pylint: disable=unsubscriptable-object
         StructureData(ase=original_atoms).get_formula(mode='hill', separator=' ')
+    )
 
     # If the number of reduced atoms multiplies the number of non-reduced
     # atoms, the new Z value can be calculated.
@@ -211,6 +213,6 @@ def refine_inline(node):
         old_Z = node.values[name]['_cell_formula_units_Z']
         if len(original_atoms) % len(refined_atoms):
             new_Z = old_Z * len(original_atoms) // len(refined_atoms)
-            cif.values[name]['_cell_formula_units_Z'] = new_Z
+            cif.values[name]['_cell_formula_units_Z'] = new_Z  # pylint: disable=unsubscriptable-object
 
     return {'cif': cif}
